{% extends "vacancies/vacancies_base.html" %}
{% load i18n %}

{% block content %}

    <div class="container">
        <h1>{% trans "Vacancy details" %}</h1>
        <hr>

        {{ vacancy }}

    </div>

{% endblock %}
