{% extends "vacancies/vacancies_base.html" %}
{% load i18n %}

{% block content %}

    <div class="container">
        <h1>{% trans "Public Vacancies" %}</h1>
        <hr>
        <ul>
            {% for vacancy in public_vacancies %}
                <li>
                    <a href="{{ vacancy.get_absolute_url }}">{{ vacancy }}</a>
                </li>
            {% empty %}
                <p class="lead text-center">- {% trans 'Currently there are no public vacancies available' %} -</p>
            {% endfor %}
        </ul>
    </div>

{% endblock %}
